@@ -1,7 +1,6 @@
 from .pycritty import parser, subparsers
-from .set import set_parser
-from .print import print_parser
-from .list import list_parser
+from .ls import list_parser
 from .save import save_parser
 from .load import load_parser
 from .install import install_parser
+from .rm import remove_parser
